@@ -130,14 +130,13 @@ class OTRSClient():
         )
         return [CoverageTicket(t) for t in tickets]
 
-    def get_ticket_by_number(self, ticket_number):
+    def get_ticket_by_number(self, ticket_number, dynamic_fields=False):
         """
         Search a OTRS Process Ticket by its number.
         Returns a PyOTRS Ticket object if found.
         """
         ticket = self.client.ticket_get_by_number(
-            ticket_number,
-            dynamic_fields=False
+            ticket_number, dynamic_fields=dynamic_fields
         )
         return ticket
 
