@@ -6,8 +6,8 @@ class MobileData:
         has_sim, type, previous_owner_vat, previous_owner_name,
         previous_owner_surname, previous_provider, product, delivery_street,
         delivery_city, delivery_zip_code, delivery_state, technology,
-        activation_notes="", notes="", is_grouped_with_fiber=False,
-        fiber_linked="",
+        sim_delivery_tracking_code, activation_notes="", notes="",
+        is_grouped_with_fiber=False, fiber_linked="",
     ):
         self.order_id = order_id
         self.phone_number = phone_number
@@ -27,6 +27,7 @@ class MobileData:
         self.delivery_zip_code = delivery_zip_code
         self.delivery_state = delivery_state
         self.technology = technology
+        self.sim_delivery_tracking_code = sim_delivery_tracking_code
         self.activation_notes = activation_notes
         self.notes = notes
         self.is_grouped_with_fiber = is_grouped_with_fiber
