@@ -19,6 +19,7 @@ class MobileDynamicFields(ProvisionDynamicFields):
             self._city(),
             self._subdivision(),
             self._sim_received(),
+            self._sim_delivery_tracking_code(),
             self._send_sim_type(),
             self._activation_notes(),
             self._delivery_street(),
@@ -71,6 +72,12 @@ class MobileDynamicFields(ProvisionDynamicFields):
     def _send_sim_type(self):
         return DynamicField("tipusEnviamentSIM", "CH_SC_OSO_SIM")
 
+    def _sim_delivery_tracking_code(self):
+        return DynamicField(
+            "CorreusTrackingCode",
+            self.service_data.sim_delivery_tracking_code
+        )
+
     def _street(self):
         return DynamicField("nomVia", self.customer_data.street)
 
