@@ -1,5 +1,5 @@
 # coding: utf-8
-from otrs_somconnexio.otrs_models.configurations.mobile_ticket import (
+from otrs_somconnexio.otrs_models.configurations.provision.mobile_ticket import (
     MobileTicketConfiguration, MobileTicketPausedConfiguration)
 from otrs_somconnexio.otrs_models.mobile_dynamic_fields import MobileDynamicFields
 from otrs_somconnexio.otrs_models.provision_ticket import ProvisionTicket
