@@ -47,7 +47,7 @@ class ChangeTariffTicket(BaseCustomerTicket):
             "correuElectronic": self.fields["subscription_email"],
             "idioma": self.fields["language"],
             "enviarNotificacio": self._transform_boolean_df(
-                self.fields["send_notification"]),
+                self.fields.get("send_notification", "1")),
         }
 
 
