@@ -63,6 +63,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
                 "previous_internal_provider",
                 "mobile_pack_contracts",
                 "all_grouped_SIMS_recieved",
+                "has_grouped_mobile_with_previous_owner",
                 "technology"
             ]
         )
@@ -660,6 +661,32 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["SIMrebuda"], "0")
 
+    def test_has_grouped_mobile_with_previous_owner_field(self):
+        self.service_data.has_grouped_mobile_with_previous_owner = True
+
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id,
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["flagDNItitularAnteriorMobils"], "1")
+
+    def test_has_no_grouped_mobile_with_previous_owner_field(self):
+        self.service_data.has_grouped_mobile_with_previous_owner = False
+
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id,
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["flagDNItitularAnteriorMobils"], "0")
+
     def test_tecnhology(self):
         self.service_data.technology = "Fibra"
 
