@@ -27,7 +27,8 @@ class MobileDataTestCase(unittest.TestCase):
             delivery_city='Alacant',
             delivery_zip_code='03140',
             delivery_state='ES-A',
-            technology="Mòbil"
+            technology="Mòbil",
+            sim_delivery_tracking_code="325"
         )
 
         self.assertIsInstance(mobile_data, MobileData)
