@@ -12,14 +12,14 @@ class MobileTicketPausedTestCase(unittest.TestCase):
     @patch('otrs_somconnexio.otrs_models.provision_ticket.Ticket')
     def test_build_mobile_paused_ticket(self, MockTicket):
         mobile_data = Mock(spec=[
-            'order_id'
+            'order_id', 'technology'
         ])
         mobile_data.order_id = 123
 
         customer_data = Mock(spec=['id'])
 
         expected_ticket_arguments = {
-            "Title": "Sol·licitud mobile {}".format(mobile_data.order_id),
+            "Title": "Ticket#{} - Només mòbil".format(mobile_data.order_id),
             "Type": MobileTicketPausedConfiguration.type,
             "Queue": MobileTicketPausedConfiguration.queue,
             "State": MobileTicketPausedConfiguration.state,
