@@ -33,7 +33,8 @@ class Router4GDataTestCase(unittest.TestCase):
             vdf_fiber_coverage=None,
             orange_fiber_coverage=None,
             type="new",
-            product="product"
+            product="product",
+            technology="4G",
         )
 
         self.assertIsInstance(router_4G_data, Router4GData)
